summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniel Veillard <veillard@src.gnome.org>2003-12-17 15:08:55 +0000
committerDaniel Veillard <veillard@src.gnome.org>2003-12-17 15:08:55 +0000
commitb286d84b86ab85abb46a54f38e94de77c4db401c (patch)
tree3ed6eb60bbf1f1d2c4fd0124c4d446b7b824509c
parent36a83169c60d5da82743043f3645cf5083977922 (diff)
downloadlibxml2-b286d84b86ab85abb46a54f38e94de77c4db401c.tar.gz
don't call the result files .out but .res as the Makefiles tend to try
* doc/examples/*: don't call the result files .out but .res as the Makefiles tend to try generating binaries for .out targets... Daniel
-rw-r--r--ChangeLog10
-rw-r--r--doc/examples/Makefile.am16
-rw-r--r--doc/examples/examples.xml12
-rwxr-xr-xdoc/examples/index.py4
-rw-r--r--doc/examples/reader1.c2
-rw-r--r--doc/examples/reader1.res (renamed from doc/examples/reader1.out)0
-rw-r--r--doc/examples/reader2.c2
-rw-r--r--doc/examples/reader3.c2
-rw-r--r--doc/examples/reader3.res (renamed from doc/examples/reader3.out)0
-rw-r--r--doc/examples/testWriter.c10
-rw-r--r--doc/examples/tree1.c2
-rw-r--r--doc/examples/tree1.res (renamed from doc/examples/tree1.out)0
-rw-r--r--doc/examples/tree2.c2
-rw-r--r--doc/examples/tree2.res (renamed from doc/examples/tree2.out)0
14 files changed, 33 insertions, 29 deletions
diff --git a/ChangeLog b/ChangeLog
index b7291630..e73ef2ec 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,13 +1,17 @@
+Wed Dec 17 16:07:33 CET 2003 Daniel Veillard <daniel@veillard.com>
+
+ * doc/examples/*: don't call the result files .out but .res as
+ the Makefiles tend to try generating binaries for .out targets...
+
Tue Dec 16 20:53:54 MST 2003 John Fleck <jfleck@inkstain.net>
- * doc/html/libxml-pattern.html - cvs add API docs for new
+ * doc/html/libxml-pattern.html: - cvs add API docs for new
pattern stuff
-
Tue Dec 16 20:40:40 MST 2003 John Fleck <jfleck@inkstain.net>
* tree.c
- * doc/*
+ * doc/*:
Elaborate in documentation discussion of xmlNewChild
and xmlNewTextChild. Thanks to Steve Lenti for pointing
out the usefulness of a more explicit explanation of the
diff --git a/doc/examples/Makefile.am b/doc/examples/Makefile.am
index e1e9b50f..4ba9427f 100644
--- a/doc/examples/Makefile.am
+++ b/doc/examples/Makefile.am
@@ -17,9 +17,9 @@ index.html: examples.xml examples.xsl
install-data-local:
$(mkinstalldirs) $(DESTDIR)$(TARGET_DIR)
- -@INSTALL@ -m 0644 $(srcdir)/*.html $(srcdir)/*.c $(srcdir)/*.xml $(srcdir)/*.xsl $(srcdir)/*.out $(DESTDIR)$(TARGET_DIR)
+ -@INSTALL@ -m 0644 $(srcdir)/*.html $(srcdir)/*.c $(srcdir)/*.xml $(srcdir)/*.xsl $(srcdir)/*.res $(DESTDIR)$(TARGET_DIR)
-EXTRA_DIST=examples.xsl index.py test1.xml examples.xml test2.xml writer.xml test3.xml tree1.out tree2.out reader1.out reader3.out
+EXTRA_DIST=examples.xsl index.py test1.xml examples.xml test2.xml writer.xml test3.xml reader1.res reader3.res tree1.res tree2.res writer1.res writer2.res writer3.res writer4.res
noinst_PROGRAMS=xpath1 parse1 parse2 tree1 tree2 testWriter reader1 reader2 reader3
@@ -71,11 +71,11 @@ reader3_LDADD= @RDL_LIBS@ $(LDADDS)
tests: $(noinst_PROGRAMS)
@(parse1 test1.xml)
@(parse2 test2.xml)
- @(tree1 test2.xml > tree1.tmp ; diff tree1.tmp tree1.out ; rm tree1.tmp)
- @(tree2 > tree2.tmp ; diff tree2.tmp tree2.out ; rm tree2.tmp)
- @(testWriter ; for i in 1 2 3 4 ; do diff writer.xml writer$$i.out ; done ; rm writer*.out)
- @(reader1 test2.xml > reader1.tmp ; diff reader1.tmp reader1.out ; rm reader1.tmp)
- @(reader2 test2.xml > reader1.tmp ; diff reader1.tmp reader1.out ; rm reader1.tmp)
- @(reader3 > reader3.tmp ; diff reader3.tmp reader3.out ; rm reader3.tmp)
+ @(tree1 test2.xml > tree1.tmp ; diff tree1.tmp tree1.res ; rm tree1.tmp)
+ @(tree2 > tree2.tmp ; diff tree2.tmp tree2.res ; rm tree2.tmp)
+ @(testWriter ; for i in 1 2 3 4 ; do diff writer.xml writer$$i.res ; done ; rm writer*.res)
+ @(reader1 test2.xml > reader1.tmp ; diff reader1.tmp reader1.res ; rm reader1.tmp)
+ @(reader2 test2.xml > reader1.tmp ; diff reader1.tmp reader1.res ; rm reader1.tmp)
+ @(reader3 > reader3.tmp ; diff reader3.tmp reader3.res ; rm reader3.tmp)
diff --git a/doc/examples/examples.xml b/doc/examples/examples.xml
index 3ee9cb5b..20e562f0 100644
--- a/doc/examples/examples.xml
+++ b/doc/examples/examples.xml
@@ -82,7 +82,7 @@
<synopsis>Navigates a tree to print element names</synopsis>
<purpose>Parse a file to a tree, use xmlDocGetRootElement() to get the root element, then walk the document and print all the element name in document order.</purpose>
<usage>tree1 filename_or_URL</usage>
- <test>tree1 test2.xml &gt; tree1.tmp ; diff tree1.tmp tree1.out ; rm tree1.tmp</test>
+ <test>tree1 test2.xml &gt; tree1.tmp ; diff tree1.tmp tree1.res ; rm tree1.tmp</test>
<author>Dodji Seketeli</author>
<copy>see Copyright for the status of this software. </copy>
<section>Tree</section>
@@ -103,7 +103,7 @@
<synopsis>Creates a tree</synopsis>
<purpose>Shows how to create document, nodes and dump it to stdout or file.</purpose>
<usage>tree2 &lt;filename&gt; -Default output: stdout</usage>
- <test>tree2 &gt; tree2.tmp ; diff tree2.tmp tree2.out ; rm tree2.tmp</test>
+ <test>tree2 &gt; tree2.tmp ; diff tree2.tmp tree2.res ; rm tree2.tmp</test>
<author>Lucas Brasilino &lt;brasilino@recife.pe.gov.br&gt;</author>
<copy>see Copyright for the status of this software </copy>
<section>Tree</section>
@@ -130,7 +130,7 @@
<synopsis>use various APIs for the xmlWriter</synopsis>
<purpose>tests a number of APIs for the xmlWriter, especially the various methods to write to a filename, to a memory buffer, to a new document, or to a subtree. It shows how to do encoding string conversions too. The resulting documents are then serialized.</purpose>
<usage>testWriter</usage>
- <test>testWriter ; for i in 1 2 3 4 ; do diff writer.xml writer$$i.out ; done ; rm writer*.out</test>
+ <test>testWriter ; for i in 1 2 3 4 ; do diff writer.xml writer$$i.res ; done ; rm writer*.res</test>
<author>Alfred Mickautsch</author>
<copy>see Copyright for the status of this software. </copy>
<section>xmlWriter</section>
@@ -175,7 +175,7 @@
<synopsis>Parse an XML file with an xmlReader</synopsis>
<purpose>Demonstrate the use of xmlReaderForFile() to parse an XML file and dump the informations about the nodes found in the process</purpose>
<usage>reader1 &lt;filename&gt;</usage>
- <test>reader1 test2.xml &gt; reader1.tmp ; diff reader1.tmp reader1.out ; rm reader1.tmp</test>
+ <test>reader1 test2.xml &gt; reader1.tmp ; diff reader1.tmp reader1.res ; rm reader1.tmp</test>
<author>Daniel Veillard</author>
<copy>see Copyright for the status of this software. </copy>
<section>xmlReader</section>
@@ -202,7 +202,7 @@
<synopsis>Parse and validate an XML file with an xmlReader</synopsis>
<purpose>Demonstrate the use of xmlReaderForFile() to parse an XML file validating the content in the process and activating options like entities substitution, and DTD attributes defaulting</purpose>
<usage>reader2 &lt;valid_xml_filename&gt;</usage>
- <test>reader2 test2.xml &gt; reader1.tmp ; diff reader1.tmp reader1.out ; rm reader1.tmp</test>
+ <test>reader2 test2.xml &gt; reader1.tmp ; diff reader1.tmp reader1.res ; rm reader1.tmp</test>
<author>Daniel Veillard</author>
<copy>see Copyright for the status of this software. </copy>
<section>xmlReader</section>
@@ -231,7 +231,7 @@
<synopsis>Show how to extract subdocuments with xmlReader</synopsis>
<purpose>Demonstrate the use of xmlTextReaderPreservePattern() to parse an XML file with the xmlReader while collecting only some subparts of the document</purpose>
<usage>reader3</usage>
- <test>reader3 &gt; reader3.tmp ; diff reader3.tmp reader3.out ; rm reader3.tmp</test>
+ <test>reader3 &gt; reader3.tmp ; diff reader3.tmp reader3.res ; rm reader3.tmp</test>
<author>Daniel Veillard</author>
<copy>see Copyright for the status of this software. </copy>
<section>xmlReader</section>
diff --git a/doc/examples/index.py b/doc/examples/index.py
index 8c64757c..2569ac3e 100755
--- a/doc/examples/index.py
+++ b/doc/examples/index.py
@@ -216,7 +216,7 @@ def dump_sections(output):
def dump_Makefile():
for file in glob.glob('*.xml'):
extras.append(file)
- for file in glob.glob('*.out'):
+ for file in glob.glob('*.res'):
extras.append(file)
Makefile="""# Beware this is autogenerated by index.py
HTML_DIR=$(datadir)/doc
@@ -237,7 +237,7 @@ index.html: examples.xml examples.xsl
install-data-local:
$(mkinstalldirs) $(DESTDIR)$(TARGET_DIR)
- -@INSTALL@ -m 0644 $(srcdir)/*.html $(srcdir)/*.c $(srcdir)/*.xml $(srcdir)/*.xsl $(srcdir)/*.out $(DESTDIR)$(TARGET_DIR)
+ -@INSTALL@ -m 0644 $(srcdir)/*.html $(srcdir)/*.c $(srcdir)/*.xml $(srcdir)/*.xsl $(srcdir)/*.res $(DESTDIR)$(TARGET_DIR)
"""
EXTRA_DIST=""
diff --git a/doc/examples/reader1.c b/doc/examples/reader1.c
index 652fe977..385f1d30 100644
--- a/doc/examples/reader1.c
+++ b/doc/examples/reader1.c
@@ -4,7 +4,7 @@
* purpose: Demonstrate the use of xmlReaderForFile() to parse an XML file
* and dump the informations about the nodes found in the process
* usage: reader1 <filename>
- * test: reader1 test2.xml > reader1.tmp ; diff reader1.tmp reader1.out ; rm reader1.tmp
+ * test: reader1 test2.xml > reader1.tmp ; diff reader1.tmp reader1.res ; rm reader1.tmp
* author: Daniel Veillard
* copy: see Copyright for the status of this software.
*/
diff --git a/doc/examples/reader1.out b/doc/examples/reader1.res
index eb48d85e..eb48d85e 100644
--- a/doc/examples/reader1.out
+++ b/doc/examples/reader1.res
diff --git a/doc/examples/reader2.c b/doc/examples/reader2.c
index 6fece7cb..784746a7 100644
--- a/doc/examples/reader2.c
+++ b/doc/examples/reader2.c
@@ -5,7 +5,7 @@
* validating the content in the process and activating options
* like entities substitution, and DTD attributes defaulting
* usage: reader2 <valid_xml_filename>
- * test: reader2 test2.xml > reader1.tmp ; diff reader1.tmp reader1.out ; rm reader1.tmp
+ * test: reader2 test2.xml > reader1.tmp ; diff reader1.tmp reader1.res ; rm reader1.tmp
* author: Daniel Veillard
* copy: see Copyright for the status of this software.
*/
diff --git a/doc/examples/reader3.c b/doc/examples/reader3.c
index e9815cd8..b68adaae 100644
--- a/doc/examples/reader3.c
+++ b/doc/examples/reader3.c
@@ -5,7 +5,7 @@
* to parse an XML file with the xmlReader while collecting
* only some subparts of the document
* usage: reader3
- * test: reader3 > reader3.tmp ; diff reader3.tmp reader3.out ; rm reader3.tmp
+ * test: reader3 > reader3.tmp ; diff reader3.tmp reader3.res ; rm reader3.tmp
* author: Daniel Veillard
* copy: see Copyright for the status of this software.
*/
diff --git a/doc/examples/reader3.out b/doc/examples/reader3.res
index 20e2e824..20e2e824 100644
--- a/doc/examples/reader3.out
+++ b/doc/examples/reader3.res
diff --git a/doc/examples/tree1.c b/doc/examples/tree1.c
index cbda7e57..7942fc68 100644
--- a/doc/examples/tree1.c
+++ b/doc/examples/tree1.c
@@ -5,7 +5,7 @@
* get the root element, then walk the document and print
* all the element name in document order.
* usage: tree1 filename_or_URL
- * test: tree1 test2.xml > tree1.tmp ; diff tree1.tmp tree1.out ; rm tree1.tmp
+ * test: tree1 test2.xml > tree1.tmp ; diff tree1.tmp tree1.res ; rm tree1.tmp
* author: Dodji Seketeli
* copy: see Copyright for the status of this software.
*/
diff --git a/doc/examples/tree1.out b/doc/examples/tree1.res
index 7b14ad0c..7b14ad0c 100644
--- a/doc/examples/tree1.out
+++ b/doc/examples/tree1.res
diff --git a/doc/examples/tree2.c b/doc/examples/tree2.c
index 125606e8..124898ee 100644
--- a/doc/examples/tree2.c
+++ b/doc/examples/tree2.c
@@ -3,7 +3,7 @@
* synopsis: Creates a tree
* purpose: Shows how to create document, nodes and dump it to stdout or file.
* usage: tree2 <filename> -Default output: stdout
- * test: tree2 > tree2.tmp ; diff tree2.tmp tree2.out ; rm tree2.tmp
+ * test: tree2 > tree2.tmp ; diff tree2.tmp tree2.res ; rm tree2.tmp
* author: Lucas Brasilino <brasilino@recife.pe.gov.br>
* copy: see Copyright for the status of this software
*/
diff --git a/doc/examples/tree2.out b/doc/examples/tree2.res
index ed001956..ed001956 100644
--- a/doc/examples/tree2.out
+++ b/doc/examples/tree2.res
diff --git a/doc/examples/testWriter.c b/doc/examples/testWriter.c
index 5a83464e..c5eaf837 100644
--- a/doc/examples/testWriter.c
+++ b/doc/examples/testWriter.c
@@ -7,7 +7,7 @@
* do encoding string conversions too. The resulting
* documents are then serialized.
* usage: testWriter
* test: testWriter ; for i in 1 2 3 4 ; do diff writer.xml writer$$i.out ; done ; rm writer*.out
* author: Alfred Mickautsch
* copy: see Copyright for the status of this software.
*/
@@ -28,16 +28,16 @@ int
main(void)
{
/* first, the file version */
- testXmlwriterFilename("writer1.out");
+ testXmlwriterFilename("writer1.res");
/* next, the memory version */
- testXmlwriterMemory("writer2.out");
+ testXmlwriterMemory("writer2.res");
/* next, the DOM version */
- testXmlwriterDoc("writer3.out");
+ testXmlwriterDoc("writer3.res");
/* next, the tree version */
- testXmlwriterTree("writer4.out");
+ testXmlwriterTree("writer4.res");
return 0;
}
@@ -7,7 +7,7 @@
* documents are then serialized.
* usage: testWriter
- * test: testWriter ; for i in 1 2 3 4 ; do diff writer.xml writer$$i.out ; done ; rm writer*.out
+ * test: testWriter ; for i in 1 2 3 4 ; do diff writer.xml writer$$i.res ; done ; rm writer*.res
* author: Alfred Mickautsch
* copy: see Copyright for the status of this software.